<?php
/**
 * Class WAO Segundo email settings file.
 *
 * @package waosegundoemail\Emails 
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}
if ( ! class_exists( 'wao_segundo_correo_config', false ) ) :

	class SegundoEmailSettings {
		public function __construct() {
			add_action('admin_menu', array($this, 'add_segundoemail_menu'));
			add_action('admin_init', array($this, 'register_segundoemail_settings'));
		}

		public function add_segundoemail_menu() {
//                        title		             menutit	     	   capacidad	        slug		funcion			 			logo 	   pos
//	add_menu_page('WAO Marketing system', 'WAOLM Marketing System', 'manage_options','waoem_config','waoem_ordenes_no_completadas',$waoem_logo, 14);

			add_menu_page(
				'Alternate Email Settings',
				'Alternate Email',
				'manage_options',
				'segundoemail_settings',
				array($this, 'render_segundoemail_settings_page'),
				'dashicons-email',
				9
			);
		}

		public function render_segundoemail_settings_page() {
			?>
			<div class="wrap">
				<h2>Alternate email configuration.</h2>
				<p>This configuration applies to sending the completed order email from another SMTP</p>
				<form method="post" action="options.php">
					<?php settings_fields('segundoemail_options_group'); ?>
					<?php do_settings_sections('segundoemail_settings'); ?>
					<?php submit_button(); ?>
				</form>
			</div>
			<?php
		}

		public function register_segundoemail_settings() {
			register_setting('segundoemail_options_group', 'segundoemail_options', array($this, 'sanitize_segundoemail_options'));

			add_settings_section('segundoemail_section', '2do SMTP configuration ', array($this, 'segundoemail_section_callback'), 'segundoemail_settings');

			add_settings_field('activo', 'Activate', array($this, 'activo_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('host', 'Host', array($this, 'host_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('username', 'Username', array($this, 'username_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('password', 'Password', array($this, 'password_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('smtptipo', 'SMTP Type', array($this, 'smtptipo_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('port', 'Port', array($this, 'port_field_callback'), 'segundoemail_settings', 'segundoemail_section');
			add_settings_field('maestro', 'Master Config', array($this, 'maestro_field_callback'), 'segundoemail_settings', 'segundoemail_section');
		}

		public function segundoemail_section_callback(){
			//echo "NARANJAS";
		}

		public function sanitize_segundoemail_options($input) {
			$sanitized_input = array();

			if (isset($input['activo'])) {
				$sanitized_input['activo'] = sanitize_text_field($input['activo']);
			}

			if (isset($input['host'])) {
				$sanitized_input['host'] = sanitize_text_field($input['host']);
			}

			if (isset($input['username'])) {
				$sanitized_input['username'] = sanitize_text_field($input['username']);
			}

			if (isset($input['password'])) {
				$sanitized_input['password'] = sanitize_text_field($input['password']);
			}

			if (isset($input['smtptipo'])) {
				$sanitized_input['smtptipo'] = sanitize_text_field($input['smtptipo']);
			}

			if (isset($input['port'])) {
				$sanitized_input['port'] = intval($input['port']);
			}

			if (isset($input['maestro'])) {
				if(is_multisite()){
					$sites=get_sites();
					foreach($sites as $site){
						switch_to_blog($site->blog_id);
							update_option('segundoemail_options',$sanitized_input);
						restore_current_blog();
					}
				}
			}

			return $sanitized_input;
		}

		public function activo_field_callback() {
			$options = get_option('segundoemail_options');
			$checkd = $options['activo']==1?"checked ":"";
			echo '<input type="checkbox" name="segundoemail_options[activo]" '.$checkd.'value="1">';
		}

		public function host_field_callback() {
			$options = get_option('segundoemail_options');
			echo '<input type="text" name="segundoemail_options[host]" value="' . esc_attr($options['host'] ?? '') . '">';
		}

		public function username_field_callback() {
			$options = get_option('segundoemail_options');
			echo '<input type="text" name="segundoemail_options[username]" value="' . esc_attr($options['username'] ?? '') . '">';
		}

		public function password_field_callback() {
			$options = get_option('segundoemail_options');
			echo '<input type="password" name="segundoemail_options[password]" value="' . esc_attr($options['password'] ?? '') . '">';
		}

		public function smtptipo_field_callback() {
			$options = get_option('segundoemail_options');
			$smtptipo = isset($options['smtptipo']) ? $options['smtptipo'] : '';
			echo '<select name="segundoemail_options[smtptipo]">
				<option value="ssl" ' . selected($smtptipo, 'ssl', false) . '>SSL</option>
				<option value="tls" ' . selected($smtptipo, 'tls', false) . '>TLS</option>
			</select>';
		}

		public function port_field_callback() {
			$options = get_option('segundoemail_options');
			echo '<input type="number" name="segundoemail_options[port]" value="' . esc_attr($options['port'] ?? '') . '">';
		}

		public function maestro_field_callback() {
			echo '<input type="checkbox" name="segundoemail_options[maestro]" '.$checked.' value="1">(Use this config for all sites.)';
		}
	}

endif;
